@@ -31,7 +31,7 @@ from  _liblip import ffi, lib as fm
 ###
 
 # global variable to support trace-info while testing
-isTest = True
+isTest = False
 
 # decorator to execute a function once
 def run_once(f):
@@ -63,31 +63,52 @@ def create_float_zeros_as_CFFI_double( n):
     return x, px
 
 def convert_py_float_to_cffi( x):
-    if isinstance( x, np.ndarray) == True:
-        px = x
-    else:
-        if x != None:
-            px = np.array( x)
-            if px.dtype != "float64": px = px.astype( float)
+    if isinstance( x, np.ndarray) or x != None:
+        if not isinstance( x, np.ndarray) or ( x.flags.c_contiguous == False) or ( x.dtype != np.float64):
+            px = np.ascontiguousarray( x, dtype = 'float64')
         else:
-            # handle None
-            px = np.array( 0.0)
-            pxcffi = ffi.cast( "double *", 0.0)    
+            px = x
+    else: 
+        # handle None
+        px = np.array( 0.0)
+    
     pxcffi = ffi.cast( "double *", px.ctypes.data)
     return px, pxcffi
 
+# def convert_py_float_to_cffi( x):
+#     if isinstance( x, np.ndarray) == True:
+#         px = np.ascontiguousarray( x, dtype = 'float64')
+#     else:
+#         if x != None:
+#             px = np.ascontiguousarray( x, dtype = 'float64')
+#         else:
+#             # handle None
+#            px = np.array( 0.0)
+#            # pxcffi = ffi.cast( "double *", 0.0)            
+#     pxcffi = ffi.cast( "double *", px.ctypes.data)
+#     return px, pxcffi
+
 
 def convert_py_int_to_cffi( x):
-    if x != None:
-        x = np.intc( x)
-        px = np.array( x)
-        pxcffi = ffi.cast( "int *", px.ctypes.data)
+    if isinstance( x, np.ndarray) or x != None:
+        if not isinstance( x, np.ndarray) or ( x.flags.c_contiguous == False):
+            px = np.ascontiguousarray( np.intc( x))    
     else: 
         # handle None
-        px = np.array( 0)
-        pxcffi = ffi.cast( "int *", 0)
+        px = np.array( 0)     
+    pxcffi = ffi.cast( "int *", px.ctypes.data)
     return px, pxcffi
    
+# def convert_py_int_to_cffi( x):
+#     if x != None:
+#         x = np.intc( x)
+#         px = np.array( x)
+#         pxcffi = ffi.cast( "int *", px.ctypes.data)
+#     else: 
+#         # handle None
+#         px = np.array( 0)
+#         pxcffi = ffi.cast( "int *", 0)
+#     return px, pxcffi
 
 ###
 # Python wrapper classes 
